@@ -24,6 +24,7 @@ import hashlib
 from client_class import HTTPSClientCertTransport
 from cert_verify import VerifyError
 from calculate.core.datavars import DataVarsCore
+from calculate.lib.utils.files import readFile
 
 VERSION = 0.11
 
@@ -84,7 +85,7 @@ def delete_old_cert(client):
 def client_post_request(cert_path, by_host):
     if os.path.exists(cert_path + 'req_id'):
         print _("You already sent a certificate signature request.")
-        print _("Request ID = %s") % open(cert_path + 'req_id', 'r').read()
+        print _("Request ID = %s") % readFile(cert_path + 'req_id')
         ans = raw_input(_("Send a new request? y/[n]: "))
         if not ans.lower() in ['y', 'yes']:
             return 0
@@ -119,7 +120,7 @@ def client_post_request(cert_path, by_host):
         new_key_req(key, cert_path, server_host_name)
 
     ip, mac, client_type = get_ip_mac_type()
-    data = open(csr_file).read()
+    data = readFile(csr_file)
     res = client.service.post_client_request(request=data, ip=ip,
                                              mac=mac, client_type=client_type)
     if int(res) < 0:
@@ -166,7 +167,7 @@ def client_get_cert(cert_path, args):
         print _('Request %s not found') % (
             cert_path + server_host_name + '.csr')
         return 1
-    request = open(cert_path + server_host_name + '.csr').read()
+    request = readFile(cert_path + server_host_name + '.csr')
     md5 = hashlib.md5()
     md5.update(request)
     md5sum = md5.hexdigest()
@@ -199,7 +200,7 @@ def client_get_cert(cert_path, args):
         cl_vars.flIniFile()
         system_ca_db = cl_vars.Get('cl_glob_root_cert')
         if os.path.exists(system_ca_db):
-            if ca_root in open(system_ca_db, 'r').read():
+            if ca_root in readFile(system_ca_db):
                 return 0
 
         cl_client_cert_dir = cl_vars.Get('cl_client_cert_dir')
